<?php
class base_onexgateway
{
    private $currency_symbol;
    private $settings;
    private $api;
    public function __construct()
    {
        $this->settings = get_option('woocommerce_OneXGateway_settings');
    }
    public function initialize()
    {
        $this->api = $this->settings['api'];
    }
    public function base($url, $data = [])
    {
        $this->initialize();
        $api = $this->api;
        $timeout = 120;
        $request[] = 'Connection: keep-alive';
        $request[] = 'Pragma: no-store, no-cache';
        $request[] = 'Cache-Control: no-store, no-cache';
        $request[] = 'Accept: */*';
        $request[] = 'DNT: 1';
        $request[] = 'Accept-Language: en-US,en;q=0.8';
        $request[] = 'Content-Type:application/json';
        $request[] = 'x-integration-key: ' . $api;
        $ch = curl_init($url);
        if (!empty($data)) {
            curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($data));
        } else {
            curl_setopt($ch, CURLOPT_POST, false);
        }
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, false);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $request);
        curl_setopt($ch, CURLOPT_ENCODING, '');
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, true);
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT,  $timeout);
        curl_setopt($ch, CURLOPT_TIMEOUT, $timeout);
        $content = curl_exec($ch);
        if (curl_errno($ch)) {
            $return = 'error:' . curl_error($ch);
        } else {
            $return = $content;
        }
        curl_close($ch);
        return $return;
    }
    public function get_networks()
    {
        $arr = [];
        $arr['btc'] = 'btc';
        $arr['eth'] = 'eth';
        $arr['trx'] = 'trx';
        $arr['1inch'] = '1inch';
        $arr['ada'] = 'ada';
        $arr['bnb'] = 'bnb';
        $arr['cake'] = 'cake';
        $arr['doge'] = 'doge';
        $arr['ltc'] = 'ltc';
        $arr['matic'] = 'matic';
        $arr['shib'] = 'shib';
        $arr['sol'] = 'sol';
        $arr['ton'] = 'ton';
        $arr['usdc'] = 'usdc';
        $arr['usdt'] = 'usdt';
        $arr['matic'] = 'matic';
        $arr['xmr'] = 'xmr';
        return $arr;
    }
    public function get_currencies()
    {
        return $this->get_networks();
    }
    public function get_currencies_allowed()
    {
        $arr = [];
        $url = 'https://api.1xgate.com/v1/settings/payment';
        $result = $this->base($url);
        if (!str_contains($result, 'error:')) {
            $result_decode = json_decode($result, true);
            if (isset($result_decode['data'])) {
                $data = $result_decode['data'];
                $currency = array_column($data, 'currency');
                $name = array_column($data, 'name');
                $arr = array_combine($currency, $name);
            }
        }
        return $arr;
    }
    public function get_currencies_network_allowed()
    {
        $arr = [];
        $url = 'https://api.1xgate.com/v1/settings/payment';
        $result = $this->base($url);
        if (!str_contains($result, 'error:')) {
            $result_decode = json_decode($result, true);
            if (isset($result_decode['data'])) {
                $data = $result_decode['data'];
                $currency = array_column($data, 'currency');
                $networks = array_column($data, 'networks');
                $arr = array_combine($currency, $networks);
            }
        }
        return $arr;
    }
    public function get_network()
    {
        return $this->settings['network'];
    }
    public function get_currency()
    {
        return $this->settings['currency'];
    }
    public function get_dollar_price()
    {
        return $this->settings['dollar_price'];
    }
    public function allow_send_email()
    {
        return $this->settings['allow_customer_email'];
    }
    public function currency_symbol()
    {
        $option = $this->settings['currency_symbol'];
        $option = trim($option);
        return !empty($option) ? $option : $this->get_currency();
    }
    public function success_threshold_percent()
    {
        return $this->settings['success_threshold_percent'];
    }
    public function check_partiallyPaid($amount, $amount_paid)
    {
        $success_threshold_percent = $this->success_threshold_percent();
        if (empty($success_threshold_percent) && $success_threshold_percent == 0) return false;
        return ((($amount - $amount_paid) * 100) / $amount) > $success_threshold_percent;
    }
    public function create_payment($order_id)
    {
        global $woocommerce;
        $order = new WC_Order($order_id);
        $total_price = $order->get_total();
        $total_price = $this->convert_price_to_currency($total_price);
        $order_send = $order_id . time() . bloginfo('name');
        $order_send = md5($order_send);
        $received_url = $order->get_checkout_order_received_url();
        $success_url = add_query_arg('status', 'success', $received_url);
        $failed_url = add_query_arg('status', 'failed', $received_url);
        $user_id = $order->get_customer_id();
        $data_send = [
            'merchantUserId' => $user_id,
            'currency' => $this->get_currency(),
            'network' => $this->get_network(),
            'amount' => $total_price,
            'orderId' => $order_send,
            'callbacks' => [
                'success' => $success_url,
                'failed' => $failed_url
            ]
        ];
        if ($this->allow_send_email()) {
            $customer_email = $order->get_billing_email();
            $data_send['merchantUserEmail'] = $customer_email;
        }
        $create_payment = $this->base('https://api.1xgate.com/v1/integrations/payments/external', $data_send);
        if (!str_contains($create_payment, 'error:')) {
            $result = json_decode($create_payment, 1);
            if (isset($result['data']) && !empty($result['data'])) {
                $data = $result['data'];
                if (isset($data['_id']) && !empty($data['_id'])) {
                    update_post_meta($order_id, 'woocommerce_OneXGateway_order_send_id_hash', $order_send);
                    update_post_meta($order_id, 'woocommerce_OneXGateway_gateway_id', $data['_id']);
                    $order->update_status('pending', __('Awaiting payment', 'woocommerce'));
                    $url_redirect = $data['link'];
                    $woocommerce->cart->empty_cart();
                    return [
                        'result' => 'success',
                        'redirect' => $url_redirect
                    ];
                }
            } else {
                if (isset($result['message']) && !empty($result['message'])) {
                    wc_add_notice(__('Payment error:', 'woothemes') . $result['message'], 'error');
                } else {
                    wc_add_notice(__('Payment error:', 'woothemes') . $result, 'error');
                }
            }
        } else {
            wc_add_notice(__('Payment error:', 'woothemes') . $create_payment, 'error');
        }
        return;
    }
    public function convert_price_to_currency($price_dollar)
    {
        $dollar_rate_price = $this->get_dollar_price();
        $price = $dollar_rate_price * $price_dollar;
        return $price;
    }
    public function get_order_id_by_order_hash($order_hash)
    {
        global $wpdb;
        $query = "SELECT post_id FROM " . $wpdb->prefix . "postmeta WHERE meta_key='woocommerce_OneXGateway_order_send_id_hash' AND meta_value= '$order_hash'";
        $option = $wpdb->get_row($wpdb->prepare($query));
        if (!empty($option)) {
            return $option->post_id;
        }
        return 0;
    }
    public  function get_page_id_from_shortcode($shortcode)
    {
        global $wpdb;
        $query = "SELECT * FROM " . $wpdb->posts . " WHERE post_content LIKE '%[" . $shortcode . "]%' AND post_status = 'publish' LIMIT 1";
        $result = $wpdb->get_row($query);
        if (!empty($result)) {
            return $result->ID;
        }
        return 0;
    }
    public static function ins()
    {
        return new self();
    }
}
function base_onexgateway_st()
{
    return  base_onexgateway::ins();
}
