<?php
function onexgateway_init_class_gateway()
{
    if (class_exists('WC_Payment_Gateway')) {
        class OneXGateway extends WC_Payment_Gateway
        {
            private $failedMassage;
            private $successMassage;
            private $api;
            private $currency;
            private $network;

            public function __construct()
            {
                $this->id = "OneXGateway";
                $this->icon = apply_filters('OneXGateway_icon_getway', plugin_dir_url(__DIR__) . 'assets_template/img/logo.png');
                $this->has_fields = false;
                $this->method_title = _('1xGate');
                $this->method_description = __('1xGate setting for wc', 'woocommerce');

                $this->init_form_fields();
                $this->init_settings();

                $this->title = $this->settings['title'];
                $this->description = $this->settings['description'];
                $this->successMassage = $this->settings['success_massage'];
                $this->failedMassage = $this->settings['failed_massage'];
                $this->api = $this->settings['api'];
                $this->currency = $this->settings['currency'];
                $this->network = $this->settings['network'];
                add_action('woocommerce_update_options_payment_gateways_' . $this->id, array($this, 'process_admin_options'));
                add_action('woocommerce_thankyou', array($this, 'thankyou_onexgateway'));
            }
            public function init_form_fields()
            {
                $base = base_onexgateway_st();
                $hook_page_id = $base->get_page_id_from_shortcode('onexgateway_webhook');
                $hook_page_url = get_permalink($hook_page_id);
                $this->form_fields = array(
                    'enabled' => array(
                        'title' => __('Enable/Disable', 'woocommerce'),
                        'type' => 'checkbox',
                        'label' => __('Enable OneXGateway', 'woocommerce'),
                        'default' => 'yes'
                    ),
                    'title' => array(
                        'title' => __('Title', 'woocommerce'),
                        'type' => 'text',
                        'description' => __('This controls the title which the user sees during checkout.', 'woocommerce'),
                        'default' => __('Crypto Currency Payment', 'woocommerce'),
                        'desc_tip' => true,
                    ),
                    'description' => array(
                        'title' => __('Customer Message', 'woocommerce'),
                        'type' => 'textarea',
                        'default' => ''
                    ),
                    'success_massage' => array(
                        'title' => __('Success Message', 'woocommerce'),
                        'type' => 'textarea',
                        'default' => 'Your payment is being processed.'
                    ),
                    'failed_massage' => array(
                        'title' => __('Failed Message', 'woocommerce'),
                        'type' => 'textarea',
                        'default' => 'Your payment is failed.'
                    ),
                    'api' => array(
                        'title' => __('Merchant API Key', 'woocommerce'),
                        'type' => 'textarea',
                        'default' => ''
                    ),
                    // 'network' => array(
                    //     'title' => __('Network', 'woocommerce'),
                    //     'type' => 'select',
                    //     'default' => 'btc',
                    //     'options' => $base->get_networks()
                    // ),
                    'currency' => array(
                        'title' => __('Currency', 'woocommerce'),
                        'type' => 'select',
                        'default' => 'btc',
                        'options' => $base->get_currencies_allowed()
                    ),
                    'network' => array(
                        'title' => __('Network', 'woocommerce'),
                        'type' => 'text',
                        // 'description' => __('This controls the title which the user sees during checkout.', 'woocommerce'),
                        'default' => __('btc', 'woocommerce'),
                        'desc_tip' => true,
                    ),
                    'currency_symbol' => array(
                        'title' => __('Currency Symbol', 'woocommerce'),
                        'type' => 'text',
                        'description' => __('If the currency key field is empty, it will be set by default.', 'woocommerce'),
                        'default' => '',
                        'desc_tip' => true,
                    ),
                    'dollar_price' => array(
                        'title' => __('Rate Price', 'woocommerce'),
                        'type' => 'text',
                        'description' => __('If your digital currency price is empty for any product, this amount will be used for conversion.', 'woocommerce'),
                        'default' => '1',
                        'desc_tip' => true,
                    ),
                    'success_threshold_percent' => array(
                        'title' => __('Success threshold percent', 'woocommerce'),
                        'type' => 'text',
                        'description' => __('If a part of the money is paid and the part that is not paid is less than the success threshold percentage, the payment will be successful.', 'woocommerce'),
                        'default' => '',
                        'desc_tip' => true,
                    ),
                    'allow_customer_email' => array(
                        'title' => __('Permission to send email to the customer', 'woocommerce'),
                        'type' => 'checkbox',
                        'label' => __('Allowed', 'woocommerce'),
                        'default' => 'yes'
                    ),
                    'webhook' => array(
                        'title' => __('WebHook Url', 'woocommerce'),
                        'type' => 'text',
                        'default' => $hook_page_url,
                        'desc_tip' => true,
                    ),
                );
            }
            public function thankyou_onexgateway($order_id)
            {
                $order = new WC_Order($order_id);
                $gateway_id = $order->get_payment_method();
                if ($gateway_id == 'OneXGateway') {
                    if (isset($_GET['status']) && $_GET['status'] == 'success') {
                        $_id = get_post_meta($order_id, 'woocommerce_OneXGateway_gateway_id', 1);
                        $get_payment = base_onexgateway_st()->base('https://api.1xgate.com/v1/integrations/payments/' . $_id);
                        $message = '';
                        if (!str_contains($get_payment, 'error:')) {
                            $data_payment = json_decode($get_payment, true);
                            if (isset($data_payment['data']) && !empty($data_payment['data'])) {
                                $data_payment = $data_payment['data'];
                                if (isset($data_payment['status'])) {
                                    $hash_order = $data_payment['orderId'];

                                    if ($data_payment['status'] == 'success') {
                                        $order->payment_complete();
                                        $message = 'Payment completed';
                                    } elseif ($data_payment['status'] == 'pending') {
                                        $order->update_status('pending');
                                        $message = 'Pending payment';
                                    } elseif ($data_payment['status'] == 'partiallyPaid') {
                                        if (base_onexgateway_st()->check_partiallyPaid($data_payment['amount'], $data_payment['amountPaid'])) {
                                            $order->update_status('partially-paid');
                                            $message = 'Pending payment';
                                        } else {
                                            $order->payment_complete();
                                            $message = 'Payment completed';
                                        }
                                    } else {
                                        $order->update_status('cancelled');
                                        $message = 'Cancelled';
                                    }
                                    $order->save();
                                }
                            } else {
                                if (isset($data_payment['message'])) {
                                    $message = $data_payment['message'];
                                } else {
                                    $message = $data_payment;
                                }
                            }
                        } else {
                            $message = $get_payment;
                        }
                    } elseif ($_GET['status'] == 'failed') {
                        $order->update_status('cancelled');
                        $order->save();
                        wc_add_notice(__('Payment failed, please try again.', 'woothemes'), 'error');
                        wp_redirect(wc_get_checkout_url());
                    } else {
                        wc_add_notice(__('Payment failed, please try again.', 'woothemes'), 'error');
                        wp_redirect(wc_get_checkout_url());
                        $message = 'failed';
                    }
                    add_filter('woocommerce_thankyou_order_received_text', function ($thank_you_msg) use ($message) {
                        return $message;
                    });
                }
            }

            public function process_payment($order_id)
            {
                return base_onexgateway_st()->create_payment($order_id);
            }
        }
    }
}
add_action('plugins_loaded', 'onexgateway_init_class_gateway');
function  onexgateway_add_gateways($methods)
{
    $methods[] = 'OneXGateway';
    return $methods;
}
add_filter('woocommerce_payment_gateways', 'onexgateway_add_gateways');
