<?php

class WC_REST_1xagateway
{
    private $base_url = "1xgate-gateway";
    private $version = "1";
    public function __construct()
    {
        add_action('rest_api_init', [$this, 'register_rest_route']);
    }
    public function register_rest_route()
    {
        $base_url = $this->base_url;
        $version = $this->version;
        $url = $this->base_url . "/v" . $version;
        register_rest_route($url, '/webhook/', array(
            'methods' => 'POST',
            'callback' => [
                $this,
                'webhook'
            ],
            'permission_callback' => '__return_true', // در عمل باید این مقدار را به درستی تعیین کنید
        ));
    }
    public function webhook($request)
    {
        $_id = $request->get_param('_id');
        $status = 403;
        $response = [
            'message' => "Not allowed to access webhook"
        ];
        if (isset($_id)) {
            $get_payment = base_onexgateway_st()->base('https://api.1xgate.com/v1/integrations/payments/' . $_id);
            if (!str_contains($get_payment, 'error:')) {
                $data_payment = json_decode($get_payment, true);
                if (isset($data_payment['data']) && !empty($data_payment['data'])) {
                    $data_payment = $data_payment['data'];
                    if (isset($data_payment['status'])) {
                        $hash_order = $data_payment['orderId'];
                        $order_id = (base_onexgateway_st()->get_order_id_by_order_hash($hash_order));
                        $order = new WC_Order($order_id);
                        if ($data_payment['status'] == 'success') {
                            $order->payment_complete();
                        } elseif ($data_payment['status'] == 'pending') {
                            $order->update_status('pending');
                        } elseif ($data_payment['status'] == 'expired') {
                            $order->update_status('failed');
                        } elseif ($data_payment['status'] == 'partiallyPaid') {
                            if (base_onexgateway_st()->check_partiallyPaid($data_payment['amount'], $data_payment['amountPaid'])) {
                                $order->update_status('partially-paid');
                            } else {
                                // $order->update_status('processing');
                                $order->payment_complete();
                            }
                        } else {
                            $order->update_status('cancelled');
                        }
                        $order->save();
                        $status = 200;
                        $response = [
                            'code' => 'success',
                            'order' => $order_id,
                            'status' => $data_payment['status']
                        ];
                    } else {
                        $status = 404;
                        $response = [
                            'code' => 'error',
                            'message' => 'Invalid'
                        ];
                    }
                } else {
                    if (!isset(json_decode($get_payment, true)['message'])) {
                        $status = 404;
                        $response = [
                            'code' => 'error',
                            'message' => ''
                        ];
                    } else {
                        $status = 500;
                        $response = [
                            'code' => 'error',
                            'message' => json_decode($get_payment, true)['message']
                        ];
                    }
                }
            } else {
                if (!isset(json_decode($get_payment, true)['message'])) {
                    $status = 404;
                    $response = [
                        'code' => 'error',
                        'message' => ''
                    ];
                } else {
                    $status = 500;
                    $response = [
                        'code' => 'error',
                        'message' => json_decode($get_payment, true)['message']
                    ];
                }
            }
        }
        return new WP_REST_Response($response, $status);
    }
}
$rest_api = new WC_REST_1xagateway();
